# matemagica


The matemagica package is used to perform some math operations more intuitively:
- Addiction (adicao)
- Subtraction (subtracao)
- Multiplication (multiplicacao)
- Division (divisao)
- Potentiation (potenciacao)
- Root (radiciacao)


## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install matemagica

```bash
pip install matemagica
```

## Usage

```python
from matemagica import operacoes

operacoes.nome_operacao()
```

## Author
Leonardo

## License
[MIT](https://choosealicense.com/licenses/mit/)